@@ -26,7 +26,7 @@ class bcolors:
 class AgentLifeCycle:
 
     # default configuration of containers and images
-    _docker_container_names = ["cgs_agent","cgs_diagnostics_agent","remote_intervention_agent","ecs_server","cgs_diagnostics_ecs_api","cgs_diagnostics_streamer_api","rosbridge"]
+    _docker_container_names = ["cgs_diagnostics_agent","remote_intervention_agent","cgs_diagnostics_ecs_api","cgs_diagnostics_streamer_api"]
     _docker_images = {}
     _docker_images["remote_intervention_agent"] = "412284733352.dkr.ecr.ap-southeast-1.amazonaws.com/remote_intervention_agent:latest"
     _docker_images["cgs_diagnostics_agent"] = "412284733352.dkr.ecr.ap-southeast-1.amazonaws.com/cognicept_diagnostics_agent:latest"
@@ -62,7 +62,7 @@ class AgentLifeCycle:
             with open(latest_log_loc_file_path) as txt_file:                
                 latest_log_loc_temp = txt_file.readline()
                 latest_log_loc_temp = latest_log_loc_temp[:-1]
-                latest_log_loc = latest_log_loc_temp.replace("/$HOME/.cognicept/","")
+                latest_log_loc = latest_log_loc_temp.replace(".cognicept/","")
         except:
             cgs_agent_status = f"{bcolors.FAIL}UNKNOWN{bcolors.ENDC}"
         
@@ -143,7 +143,7 @@ class AgentLifeCycle:
             for key,value in ri_agent_status.items():
                 if(value != ""):
                     continue
-                matches = re.search(rf'^.*{key}:: STATUS:: (?P<status>.*)\\.*$', str(line))
+                matches = re.search(rf'^.*{key}:: STATUS:: (?P<status>.*).*$', str(line))
                 if(matches is not None):
                     ri_agent_status[key] = matches.groups(0)[0]
             if(ri_agent_status["AGENT"] != "" and ri_agent_status["WEBRTC"] != "" and ri_agent_status["WEBSOCKET"] != ""):
@@ -163,7 +163,9 @@ class AgentLifeCycle:
     def restart(object, args):
         print("Restarting agents")
         object.remove_agents(args)
-        object.run(args)
+        result = object.run(args)
+        return result
+
 
     def remove_agents(object, args):   
         client = docker.from_env()
@@ -175,22 +177,27 @@ class AgentLifeCycle:
                 container.stop(timeout=10)
                 container.remove()
                 print(f"{bcolors.OKBLUE}DONE{bcolors.ENDC}")
+                return True
             except docker.errors.NotFound:
                 print(f"{bcolors.WARNING}NOT FOUND{bcolors.ENDC}")                	
+                return True
             except docker.errors.APIError:
                 print(f"{bcolors.FAIL}ERROR{bcolors.ENDC}")
+                return False
     
     def run(object, args):
         object._agent_run_options = {}
-        object._agent_run_options["cgs_agent"] = {"command": "start_cognicept_agent.py","volumes":{args.config.config_path + "agent/logs/": {"bind": "/app/logs", "mode":"rw"}},"network_mode": "host"}
+        object._agent_run_options["cgs_agent"] = {"command": "start_cognicept_agent.py","volumes":{args.config.config_path + "agent/logs/": {"bind": "/root/.cognicept/agent/logs", "mode":"rw"}},"network_mode": "host"}
         object._agent_run_options["cgs_diagnostics_agent"] = {"command": "roslaunch rosrect-listener-agent listener-agent.launch" ,"volumes":{args.config.config_path + "agent/logs/": {"bind": "/root/.cognicept/agent/logs", "mode":"rw"}} ,"network_mode": "host"}        
         object._agent_run_options["ecs_server"] = {"command": "/ecs_api_server/ecs_endpoint.py","network_mode": "host"}
         object._agent_run_options["cgs_diagnostics_ecs_api"] = {"command": "/ecs_api_server/ecs_endpoint.py" ,"network_mode": "host"}
         object._agent_run_options["cgs_diagnostics_streamer_api"] = {"command": "/data_streamer/streamer_endpoint.py" ,"network_mode": "host"}
         object._agent_run_options["remote_intervention_agent"] = {"command": "rosrun remote_intervention_agent cognicept_agent_node" ,"network_mode": "host"}        
         object._agent_run_options["rosbridge"] = {"command": "roslaunch rosbridge_server rosbridge_websocket.launch" ,"network_mode": "host"}  
+        object._agent_run_options["test"] = {"command": "bash"}
         client = docker.from_env()
         print("RUN: ")
+        success_flag = True
         for container_name in object._docker_container_names:
             print("   - " + container_name, end = ': ', flush=True)
             try:
@@ -207,8 +214,11 @@ class AgentLifeCycle:
                 print(f"{bcolors.WARNING}ALREADY EXISTS{bcolors.ENDC} (run `cognicept update`)")
             except docker.errors.ImageNotFound:
                 print(f"{bcolors.WARNING}IMAGE NOT FOUND{bcolors.ENDC} (run `cognicept update`)")
+                success_flag = False
             except docker.errors.APIError:
                 print(f"{bcolors.FAIL}DOCKER ERROR{bcolors.ENDC}")
+                success_flag = False
+        return success_flag
     
     def run_orbitty(object, args):
         os.system("xhost +local:root")
@@ -248,21 +258,21 @@ class AgentLifeCycle:
         headers = {"Authorization": "Bearer " + token}
         try:
             resp = requests.get( args.config.get_cognicept_api_uri() + "aws/assume_role/ecr", headers= headers, timeout = 5)
+            
+            if resp.status_code != 200:
+                print(f'Cognicept REST API error: `{args.config.get_cognicept_api_uri()}` responded with {resp.status_code}')
+                return False     
         except requests.exceptions.Timeout:
             print("Cognicept REST API error: time out.")
-            return
+            return False
         except requests.exceptions.TooManyRedirects:
             print("Cognicept REST API error: Wrong endpoint.")
-            return
-        except requests.exceptions.RequestException as e:
+            return False
+        except:
             print("Cognicept REST API error")
-            raise SystemExit(e)
+            return False
 
 
-        if resp.status_code != 200:
-            print('Cognicept REST API error: ' + resp.json()["message"])
-            return        
-
         ecr_client = boto3.client('ecr', region_name='ap-southeast-1', aws_access_key_id=resp.json()["AccessKeyId"], aws_secret_access_key = resp.json()["SecretAccessKey"], aws_session_token = resp.json()["SessionToken"])
         print("Info: This may take a while depending on your connection.")
         
@@ -275,10 +285,12 @@ class AgentLifeCycle:
             result = docker_client.login(username, password, registry=registry, reauth=True)
         except docker.errors.APIError:
             print("You don't have ECR repository permissions. Check you AWS credentials with Cognicept team.")
+            return False
 
         images = set(object._docker_images.values())
         N = len(images)
         i = 0
+        success_flag = True
         for image_name in images:
             i = i + 1
             try:
@@ -290,6 +302,8 @@ class AgentLifeCycle:
                 print(f"\r[{i}/{N}] {image_name} - {bcolors.OKBLUE}OK{bcolors.ENDC}\033[K")                
             except docker.errors.ImageNotFound:
                 print(f"\r[{i}/{N}] {image_name} - {bcolors.FAIL}FAILED{bcolors.ENDC}\033[K")
+                success_flag = False
 
         print("Info: Run `cognicept restart` to redeploy updated agents.")
+        return success_flag
         
