@@ -102,23 +102,24 @@ class Configuration:
         
         try:
             resp = requests.post(object.get_cognicept_api_uri() + 'user/login', json = {"username": username, "password": password}, timeout = 5)
+            if resp.status_code != 200:
+                print('Login error: wrong credentials.')
+                return False
+            
+            object.config["COGNICEPT_JWT"] = resp.json()["access_token"]            
         except requests.exceptions.Timeout:
             print("Cognicept REST API error: time out.")
             return
         except requests.exceptions.TooManyRedirects:
             print("Cognicept REST API error: Wrong endpoint.")
             return
-        except requests.exceptions.RequestException as e:
+        except:
             print("Cognicept REST API error")
-            raise SystemExit(e)
-
-        if resp.status_code != 200:
-            print('Login error: wrong credentials.')
-            return False
-        
-        object.config["COGNICEPT_JWT"] = resp.json()["access_token"]
+            raise SystemExit()
         object.save_config()
 
+        
+
         return True
 
     def get_cognicept_jwt(object):
